@@ -95,7 +95,7 @@ class extractor:
         for fix_par in self._l_fix:
             l_par_name = []
             for par_name, par in self._d_par.items():
-                if par_name.startswith(fix_par):
+                if fix_par in par_name:
                     l_par_name.append(par_name)
                     self._add_fixed_par(par)
 
@@ -157,7 +157,9 @@ class extractor:
         ndset = len(self._d_eff)
 
         if self._cov.shape != (ndset, ndset):
-            log.error(f'Covariance matrix has wrong shape: {self._cov.shape}')
+            log.error(f'Covariance matrix has wrong shape')
+            log.error(f'Expected: {ndset} x {ndset}')
+            log.error(f'Found: {self._cov.shape}')
             raise
     #--------------------------------
     def _check_rjpsi(self):
@@ -438,6 +440,17 @@ class extractor:
 
         return stats_str
     #--------------------------------
+    def _get_legend(self):
+        d_leg         = {}
+        d_leg['prc']  = r'$\psi(2S) + c\bar{c}$'
+        d_leg['bpks'] = r'$B^+\to K^{*+}e^+e^-$'
+        d_leg['bdks'] = r'$B^0\to K^{*0}e^+e^-$'
+        d_leg['bsph'] = r'$B_s\to \phi e^+e^-$'
+        d_leg['bpk1'] = r'$B^+\to K_{1}e^+e^-$'
+        d_leg['bpk2'] = r'$B^+\to K_{2}e^+e^-$'
+
+        return d_leg
+    #--------------------------------
     def _plot(self, data, model, results, component, stacked=None):
         if self._plt_dir is None:
             return
@@ -445,7 +458,13 @@ class extractor:
         stats = self._get_stats(model, data, is_muon = component.startswith('mm_') )
 
         obj=zfp(data=data, model=model, result=results)
-        obj.plot(nbins=60, stacked=stacked, ext_text=stats) 
+        obj.plot(nbins=60, d_leg = self._get_legend(), stacked=stacked, ext_text=stats) 
+        if   'ee'in component and 'TOS' in component:
+            obj.axs[0].set_ylim(0, 120)
+        elif 'mm'in component and 'TOS' in component:
+            obj.axs[0].set_ylim(0, 250)
+        elif 'ee'in component and 'TIS' in component:
+            obj.axs[0].set_ylim(0,  70)
 
         obj.axs[0].grid()
         obj.axs[1].set_ylim(-5, 5)
