@@ -4,12 +4,15 @@ import math
 import re
 import os
 import pprint
+import extset
 import matplotlib.pyplot as plt
 
-from scipy.stats import poisson
-from logzero     import logger       as log
-from bdt_scale   import scale_reader as scl_rdr
+from scipy.stats        import poisson
+from bdt_scale          import scale_reader as scl_rdr
+#from hqm.model.settings import settings     as hqm_set
+from log_store          import log_store
 
+log = log_store.add_logger(name='rk_extractor:rkex_model')
 #----------------------------------------------------
 class model:
     def __init__(self, rk=1, preffix='', d_eff=None, d_nent=None, l_dset=None):
@@ -22,7 +25,7 @@ class model:
         d_nent (dict): Stores number of B -> llK entries, before selection, e.g. {r1 : 23235}
         l_dset (list): List of datasets for which the models should be created, if None, do it for all datasets i.e. r1_TOS, r2p1_TOS...
         '''
-        self._obs        = zfit.Space('x', limits=(4800, 6000))
+        self._obs        = zfit.Space('x', limits=(4500, 6100))
         self._rk         = rk
         self._preffix    = preffix
         self._d_eff      = d_eff 
@@ -31,15 +34,18 @@ class model:
 
         self._l_all_kind = None
         self._d_bdt_wp   = None
+        self._bdt_bin    = None
 
         zfit.settings.changed_warnings.hesse_name = False
 
-        self._eff_fac_vers= 'v2'
-        self._norm_vers   = 'v7'
+        self._nbin        = 80
+        self._bdt_eff_vers= 'v1' #For correcting signal yield for BDT WP
+        self._norm_vers   = 'v44'
         self._msid_vers   = 'v4'
-        self._comb_vers   = 'v9'
+        self._comb_vers   = 'v1'
         self._l_all_dset  = ['r1', 'r2p1', '2017', '2018'] 
         self._d_lumi      = {'r1' : 3, 'r2p1' : 1.9, '2017' : 1.7, '2018' : 2.1}
+        self._scal_vers   = None #For scaling between signal and rare PRec
         self._l_dset      = None
         self._d_mod       = None
         self._out_dir     = None
@@ -49,6 +55,11 @@ class model:
     def _initialize(self):
         if self._initialized:
             return
+        log.info('Starting initializing')
+
+        if self._bdt_bin is None:
+            log.error('No BDT bin was specified')
+            raise
 
         if self._d_eff is None:
             log.error(f'No efficiencies found, cannot provide data')
@@ -64,34 +75,57 @@ class model:
         self._check_kind()
         self._cache_model()
 
+        log.info('Finished initializing')
+
         self._initialized = True
     #---------------------------------------------------------------
     def _set_kinds(self):
+        log.debug(f'Setting model kinds')
         self._l_all_kind = []
-        self._l_all_kind.append('cmb_ee:use_etos') #Will add combinatorial to all models 
-        self._l_all_kind.append('sb_fits')         #Will add combinatorial to all models and float its yield, used for sideband fits
+        self._l_all_kind.append(r'sig_MTOS:sys\d{1}')
+        self._l_all_kind.append(r'cmb_MTOS:sys\d{1}')
+
+        self._l_all_kind.append(r'sig_ETOS:sys\d{1}')
+        self._l_all_kind.append(r'cpr_ETOS:sys\d{1}')
+        self._l_all_kind.append(r'cmb_ETOS:sys\d{1}')
+
+        self._l_all_kind.append(r'rpr_ETOS:bts\d+')
+        self._l_all_kind.append(r'cpr_ETOS:bts\d+')
     #---------------------------------------------------------------
     @property
-    def bdt_wp(self):
-        return self._d_bdt_wp
+    def bdt_bin(self):
+        return self._bdt_bin
 
-    @bdt_wp.setter
-    def bdt_wp(self, value):
+    @bdt_bin.setter
+    def bdt_bin(self, value):
         '''
-        If used, will use a new WP for the model. e.g. the signal normalization will be updated
+        Will take an integer and use it to configure the components for different BDT bins
+        '''
+        log.info(f'Using {value}th BDT bin')
+        self._bdt_bin      = value
 
-        Parameters:
-        value (dict): Dictionary mapping BDT to new WP, e.g. {'BDT_cmb' : 0.1, 'BDT_prc' : 0.6}
-        '''
-        self._d_bdt_wp = value
-    #----------------------------------------------------
+        d_bdt_wp, vra, vcc = extset.get_bdt_bin_settings(bdt_bin = value)
+        self._scal_vers    = vra
+        self._d_bdt_wp     = d_bdt_wp 
+        #hqm_set.version    = vcc 
+    #---------------------------------------------------------------
     def _check_kind(self):
-        if self._kind is None:
+        log.debug(f'Checking model kinds')
+        if self._kind == 'nom':
+            log.debug('Using nominal model')
             return
 
-        if self._kind not in self._l_all_kind:
+        found = False
+        for kind in self._l_all_kind:
+            if re.match(kind, self._kind):
+                found = True
+                break
+
+        if not found: 
             log.error(f'Model of kind {self._kind} not supported')
             raise
+        else:
+            log.debug(f'Using model of kind: {self._kind}')
     #----------------------------------------------------
     @property
     def out_dir(self):
@@ -117,11 +151,12 @@ class model:
         '''
         Parameters
         -----------------
-        kind (str): Will define the type of PDF, e.g. "signal:alt_1", if not specified, will use nominal model
+        kind (str): Will define the type of PDF, e.g. "signal:sys1", if not specified, will use nominal model
         '''
         self._kind = value
     #----------------------------------------------------
     def _get_ds_model(self, ds, nent_mm, nent_ee):
+        log.info('Getting model')
         self._pdf_mm = self._get_pdf(preffix=f'mm_{ds}', nent=nent_mm)
         self._pdf_ee = self._get_pdf(preffix=f'ee_{ds}', nent=nent_ee)
     
@@ -148,9 +183,9 @@ class model:
             log.info('Using nominal WP efficiencies')
             return
 
-        log.info('---------------------')
+        log.debug('---------------------')
         log.info('Updating efficiencies')
-        log.info('---------------------')
+        log.debug('---------------------')
         for dset_trig in self._l_dset:
             if dset_trig in ['all_TOS', 'all_TIS']:
                 for single_ds in [ dset_trig.replace('all', dset) for dset in self._l_all_dset ]:
@@ -158,26 +193,31 @@ class model:
             else:
                 self._update_ds_efficiencies(dset_trig)
 
-        log.info('---------------------')
+        log.debug('---------------------')
     #---------------------------------------------------------------
     def _update_ds_efficiencies(self, dset_trig):
-        [dset, trg] = dset_trig.split('_')
+        try:
+            [dset, trg] = dset_trig.split('_')
+        except:
+            log.error(f'Cannot extract dataset and trigger from: {dset_trig}')
+            raise
+
         trig    = 'ETOS' if trg == 'TOS' else 'GTIS'
 
-        obj_ee  = scl_rdr(wp=self._d_bdt_wp, version=self._eff_fac_vers, dset=dset, trig=  trig)
+        obj_ee  = scl_rdr(wp=self._d_bdt_wp, version=self._bdt_eff_vers, dset=dset, trig=  trig)
         scl_ee  = obj_ee.get_scale()
 
-        obj_mm  = scl_rdr(wp=self._d_bdt_wp, version=self._eff_fac_vers, dset=dset, trig='MTOS')
+        obj_mm  = scl_rdr(wp=self._d_bdt_wp, version=self._bdt_eff_vers, dset=dset, trig='MTOS')
         scl_mm  = obj_mm.get_scale()
 
         eff_mm, eff_ee         = self._d_eff[dset_trig]
         EFF_mm, EFF_ee         = eff_mm * scl_mm, eff_ee * scl_ee
         self._d_eff[dset_trig] = EFF_mm         , EFF_ee
 
-        log.info(f'Dataset: {dset}')
-        log.info(f'(ee) {EFF_ee:.3e} = {scl_ee:.3e} * {eff_ee:.3e}')
-        log.info(f'(mm) {EFF_mm:.3e} = {scl_mm:.3e} * {eff_mm:.3e}')
-        log.info('')
+        log.debug(f'Dataset: {dset}')
+        log.debug(f'(ee) {EFF_ee:.3e} = {scl_ee:.3e} * {eff_ee:.3e}')
+        log.debug(f'(mm) {EFF_mm:.3e} = {scl_mm:.3e} * {eff_mm:.3e}')
+        log.debug('')
     #----------------------------------------------------
     def _get_selected_entries(self):
         d_nent_sel = {}
@@ -214,6 +254,7 @@ class model:
         return nent_mm, nent_ee
     #----------------------------------------------------
     def _cache_model(self):
+        log.info('Caching models')
         d_nent_sel = self._get_selected_entries()
         d_mod      = {}
 
