@@ -10,6 +10,7 @@ import utils_noroot as utnr
 import rk.utilities as rkut
 
 from logzero    import logger    as log
+from cmb_ck     import combiner  as cmb_ck
 from np_reader  import np_reader as np_rdr
 from mc_reader  import mc_reader as mc_rdr
 from cs_reader  import cs_reader as cs_rdr
@@ -93,8 +94,10 @@ def test_simple():
 def test_fix_pars():
     skip_test()
     log.info('Running: test_const')
+    l_dset = ['all_TOS']
 
     rdr          = np_rdr(sys='v65', sta='v63', yld='v24')
+    rdr.cache_dir= './v65_v63_v24' 
     rdr.cache    = True
     cv_sys       = rdr.get_cov(kind='sys')
     cv_sta       = rdr.get_cov(kind='sta')
@@ -104,18 +107,28 @@ def test_fix_pars():
     d_nent       = rkut.average_byields(d_byld, l_exclude=['TIS'])
     d_rare_yld   = rkut.reso_to_rare(d_nent, kind='jpsi')
 
-    mod          = model(preffix='const', d_eff=d_eff, d_nent=d_rare_yld, l_dset=['2018_TOS'])
+    mod          = model(preffix='const', d_eff=d_eff, d_nent=d_rare_yld, l_dset=l_dset)
     d_mod        = mod.get_model()
     d_dat        = mod.get_data()
     d_val, d_var = mod.get_cons()
 
-    obj          = ext(dset=['2018_TOS'])
+    if l_dset == ['all_TOS'] or l_dset == ['all_TOS', 'all_TIS']:
+        cmb                 = cmb_ck(rk=1, eff=d_eff, yld=d_rare_yld)
+        cmb.out_dir         = 'plots/combination'
+        t_comb              = cmb.get_combination()
+        d_rjpsi, d_eff, cov = t_comb
+    else:
+        cov = cv_sys + cv_sta
+
+    cov = numpy.array([[cov[0][0]]])
+
+    obj          = ext(dset=l_dset)
     obj.rjpsi    = d_rjpsi
     obj.eff      = d_eff
     obj.data     = d_dat
     obj.model    = d_mod 
-    obj.cov      = cv_sys + cv_sta 
-    obj.fix      = ['dmu', 'ck']
+    obj.cov      = cov 
+    obj.fix      = ['dmu_ee', 'dmu_mm', 'ssg_ee', 'ssg_mm', 'r0_ee', 'r1_ee', 'r2_ee', 'ncb_mm', 'ncb_ee', 'npr_ee'] 
     obj.const    = d_val, d_var
     obj.plt_dir  = 'tests/extractor/fix_pars'
     result       = obj.get_fit_result()
@@ -251,6 +264,7 @@ def test_real():
 
     rdr          = np_rdr(sys='v65', sta='v63', yld='v24')
     rdr.cache    = True
+    rdr.cache_dir='./v65_v63_v24'
     cv_sys       = rdr.get_cov(kind='sys')
     cv_sta       = rdr.get_cov(kind='sta')
     d_eff        = rdr.get_eff()
@@ -259,13 +273,16 @@ def test_real():
     d_nent       = rkut.average_byields(d_byld, l_exclude=['TIS'])
     d_rare_yld   = rkut.reso_to_rare(d_nent, kind='jpsi')
 
-    mod          = model(preffix='real', d_eff=d_eff, d_nent=d_rare_yld, l_dset=['2018_TOS'])
-    #mod.out_dir  = 'tests/extractor/real/model'
+    mod          = model(preffix='real', d_eff=d_eff, d_nent=d_rare_yld, l_dset=['all_TOS'])
+    mod.out_dir  = 'tests/extractor/real/model'
+    mod.bdt_bin  = 0
     d_mod        = mod.get_model()
     d_dat        = mod.get_data()
     d_val, d_var = mod.get_cons()
 
-    obj          = ext(dset=['2018_TOS'])
+    return
+
+    obj          = ext(dset=['all_TOS'])
     obj.rjpsi    = d_rjpsi
     obj.eff      = d_eff
     obj.cov      = cv_sys + cv_sta
@@ -531,12 +548,13 @@ def test_dmodel():
 #----------------------------------------------------
 def main():
     utnr.timer_on=True
+    test_real()
+    return
     test_fix_pars()
     test_dmodel()
     test_simple()
     test_combined()
     test_all_years()
-    test_real()
     test_real_const()
     test_json()
     test_constraint()
